export declare enum RequestErrorType {
    NETWORK_ERROR = 0,
    UNEXPECTED_RESPONSE_STATUS = 1,
    REQUEST_TIMED_OUT = 2,
    UNABLE_TO_PARSE_RESPONSE = 3
}
export interface GenericError {
    error: string;
}
export interface RequestError extends GenericError {
    timeout?: number;
    statusCode: number;
    response: string;
    responseHeaders: {
        [key: string]: string;
    };
}
export declare class ErrorUtils {
    static createRequestErrorObject(request: XMLHttpRequest, errorType: RequestErrorType): RequestError;
    /**
     * Split out for unit testing purposes.
     * Meant only to be called by ErrorUtils.createRequestErrorObject and UTs.
     */
    static createRequestErrorObjectInternal(status: number, readyState: number, response: any, responseHeaders: string, timeout: number, errorType: RequestErrorType): RequestError;
    static convertResponseHeadersToJson(request: XMLHttpRequest): {
        [key: string]: string;
    };
    /**
     * Split out for unit testing purposes.
     * Meant only to be called by ErrorUtils.convertResponseHeadersToJson, ErrorUtils.createRequestErrorObject, and UTs.
     */
    static convertResponseHeadersToJsonInternal(responseHeaders: string): {
        [key: string]: string;
    };
    private static getAdditionalNetworkErrorInfo;
    private static formatRequestErrorTypeAsString;
}
